Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(117)

Unified Diff: chrome/browser/chromeos/login/login_display.h

Issue 12704002: Support for auth code based authentication flow for both app and web UI driven flow. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase4 Created 7 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/login/login_display.h
diff --git a/chrome/browser/chromeos/login/login_display.h b/chrome/browser/chromeos/login/login_display.h
index f37293587c691e4055984c389a2dcad287f98431..5579ccc1e429883a6340426dae55d61e55607c4f 100644
--- a/chrome/browser/chromeos/login/login_display.h
+++ b/chrome/browser/chromeos/login/login_display.h
@@ -41,18 +41,16 @@ class LoginDisplay : public RemoveUserDelegate {
virtual void CreateLocallyManagedUser(const string16& display_name,
const std::string& password) = 0;
// Complete sign process with specified |username| and |password|.
// Used for new users authenticated through an extension.
- virtual void CompleteLogin(const std::string& username,
- const std::string& password) = 0;
+ virtual void CompleteLogin(const UserCredentials& credentials) = 0;
// Returns name of the currently connected network.
virtual string16 GetConnectedNetworkName() = 0;
// Sign in using |username| and |password| specified.
// Used for known users only.
- virtual void Login(const std::string& username,
- const std::string& password) = 0;
+ virtual void Login(const UserCredentials& credentials) = 0;
// Sign in as a retail mode user.
virtual void LoginAsRetailModeUser() = 0;
« no previous file with comments | « chrome/browser/chromeos/login/existing_user_controller_browsertest.cc ('k') | chrome/browser/chromeos/login/login_performer.h » ('j') | no next file with comments »
@@ -41,18 +41,16 @@ class LoginDisplay : public RemoveUserDelegate {
virtual void CreateLocallyManagedUser(const string16& display_name,
const std::string& password) = 0;
- // Complete sign process with specified |username| and |password|.
+ // Complete sign process with specified |credentials|.
// Used for new users authenticated through an extension.

Powered by Google App Engine
This is Rietveld 408576698